@echo on
@SETLOCAL
@REM  First check to make sure you are not running this 
@REM  from the \ASA9\WIN32 or WIN directory.
if exist dbeng9.exe goto WrongDirectory

@SET COLLATION=1252LATIN1
@if NOT DEFINED ISQL SET ISQL=dbisql -nogui -onerror exit
@SET PAUSE_BETWEEN_STEPS=

if NOT DEFINED DBMLSYNC_SWITCHES SET DBMLSYNC_SWITCHES=-ot remote.txt -v
SET CONS_DSN=cons
SET REMOTE_DSN=remote
SET REMOTE2_DSN=remote2
SET SQL_CUSTOMER="SELECT db_property('name') AS which_database, * FROM Customer"

@if %2. NEQ . GOTO ONE_SYNC

@if %1. EQU all. SET DBMLSYNC_SWITCHES=%DBMLSYNC_SWITCHES% -k
@if %1. EQU . SET PAUSE_BETWEEN_STEPS=1
@if %1. NEQ . GOTO %1

:ALL
@echo.
@echo.************************************************************
@echo.Stop both the MobiLink server and the database engine
@echo.Delete databases from old runs
@echo.************************************************************
@echo.
@echo on
dbmlstop -w 
dbstop -y cons
@echo off
if exist consdb attrib -r consdb\*.*
if exist remotedb attrib -r remotedb\*.*
if exist remote2db attrib -r remote2db\*.*
if exist backup attrib -r backup\*.*

@echo.
@echo.************************************************************
@echo.Remove the DSN created for the course
@echo.************************************************************
@echo.
@echo on
dbdsn -d %CONS_DSN% -y
dbdsn -d %REMOTE_DSN% -y
dbdsn -d %REMOTE2_DSN% -y
@echo off

@echo.
@echo.************************************************************
@echo.Remove all left over directories
@echo.************************************************************
@echo.
if exist consdb (echo y|del /Q consdb) 
if exist remotedb (echo y|del /Q remotedb) 
if exist remote2db (echo y|del /Q remote2db) 
if exist unload (echo y|del /Q unload)
if exist backup (echo y|del /Q backup)
if exist consdb rmdir consdb
if exist remotedb rmdir remotedb
if exist remote2db rmdir remote2db
if exist backup rmdir backup
if exist unload rmdir unload
if exist *.mle del *.mle
if exist remote.txt del remote.txt
if exist ml.txt del ml.txt

@echo.
@echo.************************************************************
@echo.  All files are cleaned up now
@echo.  The remaining files are needed to setup synchronization.
@echo.  Use CTRL-C to stop ML.BAT
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause

for /f %%i in ('cd') do @set curr_dir=%%i
cd ..
for /f %%i in ('cd') do @set db_dir=%%i
cd %curr_dir%


@echo.
@echo.************************************************************
@echo.Recreate all the ODBC DSNs 
@echo.************************************************************
@echo.
dbdsn -w %CONS_DSN% -v -c uid=dba;pwd=sql;eng=cons;dbn=cons;dbf=%curr_dir%\consdb\cons.db;links=shmem -y
dbdsn -w %REMOTE_DSN% -v -c uid=dba;pwd=sql;eng=cons;dbn=remote;dbf=%curr_dir%\remotedb\remote.db;links=shmem -y
dbdsn -w %REMOTE2_DSN% -v -c uid=dba;pwd=sql;eng=cons;dbn=remote2;dbf=%curr_dir%\remote2db\remote2.db;links=shmem -y

mkdir consdb 
mkdir remotedb 
mkdir remote2db 
mkdir unload

@echo.
@echo.************************************************************
@echo.Copy blank databases (faster than creating)
@echo.************************************************************
@echo.
@echo on
dbinit -z %COLLATION% consdb\cons.db
dbinit -z %COLLATION% remotedb\remote.db
dbinit -z %COLLATION% remote2db\remote2.db
@echo off

@echo.
@echo.************************************************************
@echo.Start the database and issue SQL commands
@echo.************************************************************
@echo.
@echo on
dbspawn -f dbeng9 -x tcpip consdb\cons.db
@echo off

:START_ML
@echo.
@echo.************************************************************
@echo.Start the MobiLink server
@echo.************************************************************
@echo.
@echo on
start /min dbmlsrv9 -zu+ -za -vcrs -x tcpip{port=2439} -c "dsn=%CONS_DSN%" -ot ml.txt 
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS
@if %1. EQU START_ML. goto DONE

:STEP1
@echo.
@echo.************************************************************
@echo.Step 1 - Create consolidated database 
@echo.
@echo.options.sql      - Some common database options for synchronization
@echo.table_common.sql - Tables used by both consolidated and remotes
@echo.procedures.sql   - Procedures used by consolidated
@echo.sync_scripts.sql - Synchronization scripts used by MobiLink
@echo.initial_data.sql - Initially populates the consolidated
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%CONS_DSN%" read options.sql; read table_common.sql; read procedures.sql; read sync_scripts.sql; read initial_data.sql;
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS

:STEP2
@echo.
@echo.************************************************************
@echo.Step 2 - Create remote databases 
@echo.
@echo.options.sql      - Some common database options for synchronization
@echo.table_common.sql - Tables used by both consolidated and remotes
@echo.remote_sub.sql   - Creates a publication, sync user, sync subscription
@echo.                   takes parameters to be reused.
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%REMOTE_DSN%" read options.sql; read table_common.sql; 
@echo off
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%REMOTE_DSN%" read remote_sub.sql [remote1] [tcpip] [localhost] [2439]
@echo off
@if not %errorlevel% EQU 0 goto DONE
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%REMOTE2_DSN%" read options.sql; read table_common.sql; 
@echo off
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%REMOTE2_DSN%" read remote_sub.sql [remote2] [tcpip] [localhost] [2439]
@echo off
@if not %errorlevel% EQU 0 goto DONE

:STEP3
@echo.
@echo.************************************************************
@echo.Step 3 - Run dbmlsync for the first time to download
@echo.         initial data for BOTH remotes.
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
dbmlsync -c "dsn=%REMOTE_DSN%" %DBMLSYNC_SWITCHES%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
dbmlsync -c "dsn=%REMOTE2_DSN%" %DBMLSYNC_SWITCHES%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS

:STEP3
@echo.
@echo.************************************************************
@echo.Step 3 - Ensure Remote1, has only remote1's rows
@echo.         and Remote2, has only remote2's rows.
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
%ISQL% -c "dsn=%REMOTE_DSN%" %SQL_CUSTOMER%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS
@echo on
%ISQL% -c "dsn=%REMOTE2_DSN%" %SQL_CUSTOMER%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS

goto DONE

:DBMLSYNC
@echo.
@echo.************************************************************
@echo.Run dbmlsync 
@echo.************************************************************
@echo.
@IF DEFINED PAUSE_BETWEEN_STEPS pause
@echo on
dbmlsync -c "dsn=%REMOTE_DSN%" %DBMLSYNC_SWITCHES%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS

@echo on
%ISQL% -c "dsn=%CONS_DSN%" %SQL_ENG_MSGS%
@echo off
@if NOT %errorlevel% EQU 0 goto ERRORS

goto DONE

:DONE
@echo.
@echo.************************************************************
@echo.All done tests.
@echo.************************************************************
@echo.

goto END

:ERRORS
@echo.
@echo.************************************************************
@echo.ERROR
@echo.Tests did not complete properly.
@echo.************************************************************
@echo.

goto END

:WrongDirectory
@echo off
cls
@echo.
@echo.************************************************************
@echo.   STOP!!
@echo.You need to create a new/empty directory and copy 
@echo.ML.BAT and the SQL files into that directory.
@echo.************************************************************
@echo.
goto END

:END
@ENDLOCAL

