/*
 * sp_ML_modify_user
 *
 * Is called by the MobiLink synchronization scripts.
 */
CREATE PROCEDURE sp_ML_modify_user( 
    INOUT @ml_user_name VARCHAR(255) 
) 
BEGIN
    SET @ml_user_name = f_Strip_UUID( @ml_user_name );
END;


/*
 * f_Strip_UUID 
 *
 * Is a utility function that will strip off the UUID if it exists.
 * A separate function is created for this, since you might also need
 * to do this is you created a custom authentication MobiLink event.
 * In that case, you will also need to strip off the UUID.
 */
CREATE FUNCTION f_Strip_UUID( 
    IN @ml_user_name VARCHAR(255) 
) 
RETURNS VARCHAR(255)
DETERMINISTIC
BEGIN
    DECLARE @colon_at INT;
    DECLARE @stripped_name VARCHAR(255);

    -- Check for the location of the : which is used as a 
    -- separator
    SET @colon_at = LOCATE( @ml_user_name, ':' );
    
    IF( @colon_at > 0 ) THEN
        -- Message statements are displayed in the minimized engine
        -- window, this is useful for debugging
        MESSAGE 'UUID: ' + 
                RIGHT( @ml_user_name, 
                    (LENGTH(@ml_user_name)-@colon_at) );

         -- Get up to the colon
        SET @stripped_name = LEFT( @ml_user_name, (@colon_at-1) );

        MESSAGE 'New MobiLink User: ' + @stripped_name; 
    ELSE
        -- Name does not contain a UUID, simply return it
        SET @stripped_name = @ml_user_name;

        MESSAGE 'No change to MobiLink User: ' + @stripped_name;
    END IF;

    RETURN @stripped_name;
END;

