PARAMETERS pUID, pPROTOCOL, pMACHINE, pPORT;

/*
 * Parameters are very useful, since you can write a routine that 
 * will generate many remote databases without customizing
 * a file for each user.
 */

-- Create the new synchronization objects
CREATE PUBLICATION "all_tables"
(
	TABLE customer
);

/*
 * Specify various options for the above publication
 *   a) Location of the MobiLink server
 *   b) What protocol to use to talk to MobiLink
 *   c) Which ScriptVersion to use on the server
 *   d) Whether the tables should locked or not during synchronization
 */
CREATE SYNCHRONIZATION SUBSCRIPTION TO "all_tables"
    TYPE '{pPROTOCOL}'
    ADDRESS 'host={pMACHINE};port={pPORT}'
    OPTION memory='2m'
          , ScriptVersion='v1.0'
          , LockTables='off';

/*
 * In order to share the same MobiLink user across databases, you must
 * still make the name unique in some manner.  
 *
 * To do that, we are combining the MobiLink user name with a UUID/GUID 
 * that will guarantee the value to be unique.
 *
 * See readme.txt for greater detail.
 */
BEGIN
    DECLARE @cmd       VARCHAR(2000);
    DECLARE @uuid      BINARY(16);
    DECLARE @sync_user VARCHAR(100);

    -- Create a new UUID/GUID
    SET @uuid = newid();
    -- Concatenate both the user and the UUID together
    SET @sync_user  = '"'
                + '{pUID}'
                + ':'
                + uuidtostr(@uuid)
                + '"';
    SET @cmd  = 'CREATE SYNCHRONIZATION USER '
                + @sync_user;

    -- Display the resulting string to the minimized engine window
    MESSAGE @cmd;            

    -- Execute the SQL command we just created
    EXECUTE IMMEDIATE @cmd;

    -- Now create a synchronization subscription for this user and
    -- the publication.
    SET @cmd  = 'CREATE SYNCHRONIZATION SUBSCRIPTION TO "all_tables"'
                + ' FOR ' + @sync_user;

    -- Display the resulting string to the minimized engine window
    MESSAGE @cmd;            

    -- Execute the SQL command we just created
    EXECUTE IMMEDIATE @cmd;
END;
 
